/*
 * Copyright 2023 teogor (Teodor Grigor)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import com.android.build.api.dsl.ApplicationExtension
import com.google.firebase.crashlytics.buildtools.gradle.CrashlyticsExtension
import org.gradle.api.Plugin
import org.gradle.api.Project
import org.gradle.api.artifacts.VersionCatalogsExtension
import org.gradle.kotlin.dsl.configure
import org.gradle.kotlin.dsl.dependencies
import org.gradle.kotlin.dsl.getByType

class AndroidApplicationFirebaseConventionPlugin : Plugin<Project> {
  override fun apply(target: Project) {
    with(target) {
      with(pluginManager) {
        // todo enable once google-services.json is in place
        apply("com.google.gms.google-services")
        apply("com.google.firebase.firebase-perf")
        apply("com.google.firebase.crashlytics")
      }

      val libs = extensions.getByType<VersionCatalogsExtension>().named("libs")
      dependencies {
        val bom = libs.findLibrary("firebase-bom").get()
        add("implementation", platform(bom))
        "implementation"(libs.findLibrary("firebase.analytics").get())
        "implementation"(libs.findLibrary("firebase.performance").get())
        "implementation"(libs.findLibrary("firebase.crashlytics").get())
      }

      extensions.configure<ApplicationExtension> {
        buildTypes.configureEach {
          // Disable the Crashlytics mapping file upload. This feature should only be
          // enabled if a Firebase backend is available and configured in
          // google-services.json.
          configure<CrashlyticsExtension> {
            mappingFileUploadEnabled = false
          }
        }
      }
    }
  }
}
