/*
 * Copyright 2023 teogor (Teodor Grigor)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package dev.teogor.ceres.ui.designsystem

import androidx.compose.foundation.layout.Box
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.ProvideTextStyle
import androidx.compose.material3.TextButton
import androidx.compose.material3.contentColorFor
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import dev.teogor.ceres.ui.theme.MaterialTheme

@Composable
fun CeresTopicTag(
  modifier: Modifier = Modifier,
  followed: Boolean,
  onClick: () -> Unit,
  enabled: Boolean = true,
  text: @Composable () -> Unit,
) {
  Box(modifier = modifier) {
    val containerColor = if (followed) {
      MaterialTheme.colorScheme.primaryContainer
    } else {
      MaterialTheme.colorScheme.surfaceVariant.copy(
        alpha = CeresTagDefaults.UnfollowedTopicTagContainerAlpha,
      )
    }
    TextButton(
      onClick = onClick,
      enabled = enabled,
      colors = ButtonDefaults.textButtonColors(
        containerColor = containerColor,
        contentColor = contentColorFor(backgroundColor = containerColor),
        disabledContainerColor = MaterialTheme.colorScheme.onSurface.copy(
          alpha = CeresTagDefaults.DisabledTopicTagContainerAlpha,
        ),
      ),
    ) {
      ProvideTextStyle(value = MaterialTheme.typography.labelSmall) {
        text()
      }
    }
  }
}

/**
 * Ceres tag default values.
 */
object CeresTagDefaults {
  const val UnfollowedTopicTagContainerAlpha = 0.5f

  // TODO: File bug
  // Button disabled container alpha value not exposed by ButtonDefaults
  const val DisabledTopicTagContainerAlpha = 0.12f
}
