/*
 * Copyright 2023 teogor (Teodor Grigor)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

@file:OptIn(ExperimentalMaterial3Api::class)

package dev.teogor.ceres.ui.designsystem

import android.R.string
import androidx.annotation.StringRes
import androidx.compose.material3.CenterAlignedTopAppBar
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBarColors
import androidx.compose.material3.TopAppBarDefaults
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.vector.ImageVector
import androidx.compose.ui.platform.testTag
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.tooling.preview.Preview
import dev.teogor.ceres.ui.icons.CeresIcons
import dev.teogor.ceres.ui.theme.MaterialTheme

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun CeresTopAppBar(
  @StringRes titleRes: Int,
  navigationIcon: ImageVector,
  navigationIconContentDescription: String?,
  actionIcon: ImageVector,
  actionIconContentDescription: String?,
  modifier: Modifier = Modifier,
  colors: TopAppBarColors = TopAppBarDefaults.centerAlignedTopAppBarColors(),
  onNavigationClick: () -> Unit = {},
  onActionClick: () -> Unit = {},
) {
  CenterAlignedTopAppBar(
    title = { Text(text = stringResource(id = titleRes)) },
    navigationIcon = {
      IconButton(onClick = onNavigationClick) {
        Icon(
          imageVector = navigationIcon,
          contentDescription = navigationIconContentDescription,
          tint = MaterialTheme.colorScheme.onSurface,
        )
      }
    },
    actions = {
      IconButton(onClick = onActionClick) {
        Icon(
          imageVector = actionIcon,
          contentDescription = actionIconContentDescription,
          tint = MaterialTheme.colorScheme.onSurface,
        )
      }
    },
    colors = colors,
    modifier = modifier.testTag("niaTopAppBar"),
  )
}

/**
 * Top app bar with action, displayed on the right
 */
@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun CeresTopAppBar(
  @StringRes titleRes: Int,
  actionIcon: ImageVector,
  actionIconContentDescription: String?,
  modifier: Modifier = Modifier,
  colors: TopAppBarColors = TopAppBarDefaults.centerAlignedTopAppBarColors(),
  onActionClick: () -> Unit = {},
) {
  CenterAlignedTopAppBar(
    title = { Text(text = stringResource(id = titleRes)) },
    actions = {
      IconButton(onClick = onActionClick) {
        Icon(
          imageVector = actionIcon,
          contentDescription = actionIconContentDescription,
          tint = MaterialTheme.colorScheme.onSurface,
        )
      }
    },
    colors = colors,
    modifier = modifier.testTag("niaTopAppBar"),
  )
}

@OptIn(ExperimentalMaterial3Api::class)
@Preview("Top App Bar")
@Composable
private fun CeresTopAppBarPreview() {
  CeresTopAppBar(
    titleRes = string.untitled,
    navigationIcon = CeresIcons.Search,
    navigationIconContentDescription = "Navigation icon",
    actionIcon = CeresIcons.MoreVert,
    actionIconContentDescription = "Action icon",
  )
}
